Salut Changelog
==============

Salut follows the Semantic Versioning standard, although not for development
before version 1. Read more at http://semvar.org


Version 0.1.2
-------------

Released on January 22nd 2012

- Include this changes file with setup


Version 0.1.1
-------------

Released on January 22nd 2012

- Add readme and license files with setup


Version 0.1.0
-------------

Released on January 22nd 2012

- First release
